#
# spec file for package gtk2-engines
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gtk2-engines
%define _name gtk-engines
Summary:        GTK+ 2 Theme Engines
License:        LGPL-2.1-or-later
Group:          System/GUI/GNOME
Version:        2.20.2
Release:        bp160.4.7
# FIXME: On new version, change <= Obsoletes to < (last checked: 2.20.2)
# FIXME: On new versions, check if bgo#607127 is solved, and if it is, enable
# the lua engine: uncomment lua-devel BuildRequires and configure options.
URL:            http://www.gnome.org
Source:         %{_name}-%{version}.tar.bz2
Source1:        README.openSUSE
#
Patch0:         gtk-engines-bnc546966-clearlooks-fix-main-menu-icon-size.patch
# PATCH-FIX-UPSTREAM gtk-engines-glib.patch bgo#664914 dimstar@opensuse.org -- FIx build with new glib: only glib.h can be included.
Patch1:         gtk-engines-glib.patch
BuildRequires:  gtk2-devel
BuildRequires:  intltool
BuildRequires:  pkg-config
# See comment below on why this is disabled
#BuildRequires:  lua-devel
# We require the exact version of gtk2 we were compiled with since the engines are located in a versioned directory
%define gtk2_ver %(rpm -q --whatprovides --qf '%%{version}' gtk2)
Requires:       gtk2-engine-clearlooks
Requires:       gtk2-engine-crux
Requires:       gtk2-engine-glide
Requires:       gtk2-engine-hcengine
Requires:       gtk2-engine-industrial
Requires:       gtk2-engine-mist
Requires:       gtk2-engine-redmond95
Requires:       gtk2-engine-thinice
Requires:       gtk2-theme-clearlooks
Requires:       gtk2-theme-crux
Requires:       gtk2-theme-industrial
Requires:       gtk2-theme-mist
Requires:       gtk2-theme-redmond95
Requires:       gtk2-theme-thinice
# Prevent missing engine failures on bi-arch systems:
%ifarch x86_64 s390x
Recommends:     %{name}-32bit = %{version}
%endif
Enhances:       gtk2
# gnome-themes had Industrial before this version (<= SuSE Linux 9.2, <= NLD9).
Conflicts:      gnome-themes < 2.11.90
# For smooth upgrades: we removed translations during 12.2 development
# FIXME: should be < with next version (last checked: 2.20.2)
Obsoletes:      %{name}-lang <= %{version}
Provides:       gtk2-engines-lang = 2.14.1
Obsoletes:      gtk2-engines-lang < 2.14.1
# bug437293
%ifarch ppc64
Obsoletes:      gnome-themes-64bit
Obsoletes:      gtk2-engines-64bit
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package installs the theme engine libraries for GTK+ 2.

%package devel
Summary:        Development files for gtk2-engines
Group:          Development/Libraries/GNOME
Requires:       %{name} = %{version}

%description devel
This package contains development files for gtk2-engines.

%package -n gtk2-engine-clearlooks
Summary:        Clearlooks GTK+ 2 Theme Engine
Group:          System/GUI/GNOME
Requires:       gtk2 = %{gtk2_ver}
Recommends:     gtk2-theme-clearlooks = %{version}

%description -n gtk2-engine-clearlooks
The Clearlooks engine was the default theme of GNOME 2 since 2.12. It is
a modular engine providing multiple styles such as glossy and gummy.

%package -n gtk2-theme-clearlooks
Summary:        Clearlooks Theme for GTK+ 2
Group:          System/GUI/GNOME
Requires:       gtk2-engine-clearlooks = %{version}
BuildArch:      noarch

%description -n gtk2-theme-clearlooks
This package provides the Clearlooks GTK+ 2 theme.

%package -n gtk2-engine-crux
Summary:        Crux GTK+ 2 Theme Engine
Group:          System/GUI/GNOME
Requires:       gtk2 = %{gtk2_ver}
Recommends:     gtk2-theme-crux = %{version}

%description -n gtk2-engine-crux
The Crux engine was a popular theme in the early GNOME 2 days.

%package -n gtk2-theme-crux
Summary:        Crux Theme for GTK+ 2
Group:          System/GUI/GNOME
Requires:       gtk2-engine-crux = %{version}
BuildArch:      noarch

%description -n gtk2-theme-crux
This package provides the Crux GTK+ 2 theme.

%package -n gtk2-engine-glide
Summary:        Glide GTK+ 2 Theme Engine
Group:          System/GUI/GNOME
Requires:       gtk2 = %{gtk2_ver}

%description -n gtk2-engine-glide
This packages provides the Glide engine for GTK+ 2, originally written
for the Glider theme.

%package -n gtk2-engine-hcengine
Summary:        HC GTK+ 2 Theme Engine
Group:          System/GUI/GNOME
Requires:       gtk2 = %{gtk2_ver}

%description -n gtk2-engine-hcengine
The High Contrast engine is targeted for usability themes, such as the
GNOME HighContrast theme.

%package -n gtk2-engine-industrial
Summary:        Industrial GTK+ 2 Theme Engine
Group:          System/GUI/GNOME
Requires:       gtk2 = %{gtk2_ver}
Recommends:     gtk2-theme-industrial = %{version}

%description -n gtk2-engine-industrial
The Industrial engine provides a simple and consistent appearance for
applications.

%package -n gtk2-theme-industrial
Summary:        Industrial Theme for GTK+ 2
Group:          System/GUI/GNOME
Requires:       gtk2-engine-industrial = %{version}
BuildArch:      noarch

%description -n gtk2-theme-industrial
This package provides the Industrial GTK+ 2 theme.

%package -n gtk2-engine-mist
Summary:        Mist GTK+ 2 Theme Engine
Group:          System/GUI/GNOME
Requires:       gtk2 = %{gtk2_ver}
Recommends:     gtk2-theme-mist = %{version}

%description -n gtk2-engine-mist
The Mist engine is a minimalist engine designed to provide a simple UI
experience.

%package -n gtk2-theme-mist
Summary:        Mist Theme for GTK+ 2
Group:          System/GUI/GNOME
Requires:       gtk2-engine-mist = %{version}
BuildArch:      noarch

%description -n gtk2-theme-mist
This package provides the Mist GTK+ 2 theme.

%package -n gtk2-engine-redmond95
Summary:        Redmond GTK+ 2 Theme Engine
Group:          System/GUI/GNOME
Requires:       gtk2 = %{gtk2_ver}
Recommends:     gtk2-theme-redmond95 = %{version}

%description -n gtk2-engine-redmond95
The Redmond engine and theme are designed to mimic the appearance of
another well known OS.

%package -n gtk2-theme-redmond95
Summary:        Redmond Theme for GTK+ 2
Group:          System/GUI/GNOME
Requires:       gtk2-engine-redmond95 = %{version}
BuildArch:      noarch

%description -n gtk2-theme-redmond95
The Redmond engine and theme are designed to mimic the appearance of
another well known OS.

%package -n gtk2-engine-thinice
Summary:        ThinIce GTK+ 2 Theme Engine
Group:          System/GUI/GNOME
Requires:       gtk2 = %{gtk2_ver}
Recommends:     gtk2-theme-thinice = %{version}

%description -n gtk2-engine-thinice
The ThinIce engine features thin edges and Icy Colors, and provides a
simple mostly clean appearance many find satisfying.

%package -n gtk2-theme-thinice
Summary:        ThinIce Theme for GTK+ 2
Group:          System/GUI/GNOME
Requires:       gtk2-engine-thinice = %{version}
BuildArch:      noarch

%description -n gtk2-theme-thinice
This package provides the ThinIce GTK+ 2 theme.

%prep
%autosetup -p1 -n %{_name}-%{version}
cp -a %{S:1} .

%build
%configure \
        --enable-animation
#        --enable-lua \
#        --with-system-lua
make %{?jobs:-j%jobs}

%install
%makeinstall
rm $RPM_BUILD_ROOT%{_libdir}/gtk-2.0/*/engines/*.*a
# Remove translations: they are only needed to generate translations in xml files
rm %{buildroot}%{_datadir}/locale/*/LC_MESSAGES/%{_name}.mo
# Fix spurious-executable-perm on source files; test will fail if we can remove this
test -x engines/mist/AUTHORS
chmod a-x engines/mist/AUTHORS

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-, root, root)
%doc AUTHORS COPYING ChangeLog NEWS README README.openSUSE

%files -n gtk2-engine-clearlooks
%defattr(-, root, root)
%doc engines/clearlooks/AUTHORS COPYING NEWS README
%{_libdir}/gtk-2.0/*/engines/libclearlooks.so
%dir %{_datadir}/gtk-engines/
%{_datadir}/gtk-engines/clearlooks.xml

%files -n gtk2-theme-clearlooks
%defattr(-, root, root)
%{_datadir}/themes/Clearlooks/

%files -n gtk2-engine-crux
%defattr(-, root, root)
%doc engines/crux/AUTHORS COPYING NEWS README
%{_libdir}/gtk-2.0/*/engines/libcrux-engine.so
%dir %{_datadir}/gtk-engines/
%{_datadir}/gtk-engines/crux-engine.xml

%files -n gtk2-theme-crux
%defattr(-, root, root)
%{_datadir}/themes/Crux/

%files -n gtk2-engine-glide
%defattr(-, root, root)
%doc engines/glide/AUTHORS COPYING NEWS README
%{_libdir}/gtk-2.0/*/engines/libglide.so
%dir %{_datadir}/gtk-engines/
%{_datadir}/gtk-engines/glide.xml

%files -n gtk2-engine-hcengine
%defattr(-, root, root)
%doc engines/hc/AUTHORS COPYING NEWS README
%{_libdir}/gtk-2.0/*/engines/libhcengine.so
%dir %{_datadir}/gtk-engines/
%{_datadir}/gtk-engines/hcengine.xml

%files -n gtk2-engine-industrial
%defattr(-, root, root)
%doc engines/industrial/AUTHORS COPYING NEWS README
%{_libdir}/gtk-2.0/*/engines/libindustrial.so
%dir %{_datadir}/gtk-engines/
%{_datadir}/gtk-engines/industrial.xml

%files -n gtk2-theme-industrial
%defattr(-, root, root)
%{_datadir}/themes/Industrial/

%files -n gtk2-engine-mist
%defattr(-, root, root)
%doc engines/mist/AUTHORS COPYING NEWS README
%{_libdir}/gtk-2.0/*/engines/libmist.so
%dir %{_datadir}/gtk-engines/
%{_datadir}/gtk-engines/mist.xml

%files -n gtk2-theme-mist
%defattr(-, root, root)
%{_datadir}/themes/Mist/

%files -n gtk2-engine-redmond95
%defattr(-, root, root)
%doc engines/redmond/AUTHORS COPYING NEWS README
%{_libdir}/gtk-2.0/*/engines/libredmond95.so
%dir %{_datadir}/gtk-engines/
%{_datadir}/gtk-engines/redmond95.xml

%files -n gtk2-theme-redmond95
%defattr(-, root, root)
%{_datadir}/themes/Redmond/

%files -n gtk2-engine-thinice
%defattr(-, root, root)
%doc engines/thinice/AUTHORS COPYING NEWS README
%{_libdir}/gtk-2.0/*/engines/libthinice.so
%dir %{_datadir}/gtk-engines/
%{_datadir}/gtk-engines/thinice.xml

%files -n gtk2-theme-thinice
%defattr(-, root, root)
%{_datadir}/themes/ThinIce/

%files devel
%defattr(-, root, root)
%{_libdir}/pkgconfig/*.pc

%changelog
* Tue Mar  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: the -32bit packages are no longer needed and
  have not been part of Tumbleweed for a while already (build for
  i586 only enabled in LegacyX86).
* Tue Nov 28 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup instead of %%setup/%%patch.
- Fix baselibs.conf: reference correct name of hcengine.
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Fri Jan 13 2012 vuntz@opensuse.org
- Manually remove translations in %%install and drop lang
  subpackage: the translations are useless at runtime, since they
  are integrated in the xml files.
- Add Obsoletes for gtk-engines-lang to main subpackage, for smooth
  upgrades.
* Sat Dec 24 2011 gankov@opensuse.org
- Split gtk2-engines package in subpackages for each engine and
  theme: gtk2-engine-{engine_name} and gtk2-theme-{theme_name}, for
  clearlooks, crux, glide, hcengine, industrial, mist, redmond95,
  thinice. Fix bnc#706929.
- Add Requires for all new subpackages to gtk2-engines: it is now a
  metapackage used to install all engines and themes.
- Add README.openSUSE to gtk2-engines to explain that this is a
  metapackage.
- Remove fdupes BuildRequires and call to %%fdupes since it can't be
  useful anymore with split packages.
* Sun Nov 27 2011 dimstar@opensuse.org
- Add gtk-engines-glib.patch: Fix build with newer glib, where only
  glib.h can be #include'd.
* Mon Jul 25 2011 andrea.turrini@gmail.com
- Fixed typo in description of gtk2-engines.spec
* Thu Oct 14 2010 vuntz@opensuse.org
- Use --whatprovides to find the version of gtk2 since we split
  gtk2 according to the shared library packaging policy, and there
  is no gtk2 package anymore.
* Fri Oct  1 2010 vuntz@opensuse.org
- Update to version 2.20.2:
  + Fix evolution ETree header in Clearlooks
  + Minor fixes in mist
  + Removed Xfce specific workaround from the clearlooks engine
    (bgo#616124)
  + Updated translations.
* Wed Sep 29 2010 aj@suse.de
- Change lang package Requires to Recommends since it is not
  mandatory at runtime.
* Thu May  6 2010 dimstar@opensuse.org
- Update to version 2.20.1:
  + Fixes the shadow around entries in the Clearlooks Gummy style.
- BuildRequire pgk-config for proper .pc dependencies.
* Tue Apr 27 2010 aj@suse.de
- Create devel package so that users of the base package do not
  need other development files installed.
- Fix obsoletes to not self-obsolete the package.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.20.0:
  + Increased spacing between icons and labels in Clearlooks
  + bgo#594014 - gtk-engines: system-lua check is buggy
  + Updated translations.
* Sun Jan 31 2010 jengelh@medozas.de
- Package baselibs.conf
* Sat Jan 16 2010 vuntz@opensuse.org
- Compile with animation support: add --enable-animation configure
  option.
* Fri Jan 15 2010 vuntz@opensuse.org
- Do not package en@shaw locale on openSUSE 11.2 and earlier.
* Thu Jan 14 2010 captain.magnus@opensuse.org
- Update to version 2.19.0:
  + Option to use the systems version of liblua
  + Removal of a potential endless loop in different Clearlooks
    styles
  + Support for Automake 1.11.
  + Improvements for bgo#525065 (small Clearlooks themes)
* Sat Jan  2 2010 vuntz@opensuse.org
- Update to version 2.18.5:
  + Removal of a potential infinite loop in different clearlooks
    styles
  + bgo#603445 - update to support automake 1.11 +silent build.
  + Updated translations.
* Mon Oct 19 2009 mxwu@novell.com
- Add gtk-engines-bnc546966-clearlooks-fix-main-menu-icon-size.patch
  fix bnc#546966.
* Wed Sep 30 2009 vuntz@opensuse.org
- Update to version 2.18.4:
  + bgo#595907 - liblua not disted in 2.18.3
- Changes from version 2.18.3:
  + bgo#593674 - Add --enable-system-lua configure option for
    system liblua linkage
  + bgo#594014 - system-lua check is buggy
  + Updated translations.
* Tue May 19 2009 vuntz@novell.com
- Update to version 2.18.2:
  + Changes for the git migration (doap file, ChangeLog)
  + bgo#578882 – gtk-engines-2.18.1 doesn't pass tests due to
    exported_lua
  + Updated translations.
- Add lang package: for some reasons, the translations were never
  installed before (?).
* Tue Apr 28 2009 vuntz@novell.com
- Require specific version of gtk2 we were built against, instead
  of >= 2.10.0. This helps when using various projects with more
  than one gtk2 version and the versioned directories for engines
  has changed. Fix bnc#484104.
* Tue Apr 14 2009 vuntz@novell.com
- Update to version 2.18.1:
  + Clearlooks draws the focus line of entries now correct.
  + Clearlooks now only draws a one pixel line between two adjacent
    steppers.
  + bgo#576786 – clearlooks is broken on trunk
  + bgo#576787 – export hygiene
  + bgo#572178 – Remove deprecated GTK+ symbols
  + Updated translations.
* Mon Mar 16 2009 vuntz@novell.com
- Update to version 2.18.0:
  + Improved entry progress drawing in Clearlooks.
  + Updated translations.
* Fri Mar  6 2009 vuntz@novell.com
- Update to version 2.17.4:
  + Many themes have some initial support for progressbars in
    entries.
  + Updated translations.
* Tue Feb 24 2009 vuntz@novell.com
- Drop gnome-themes-industrial-tree-insensitive-text-color.diff:
  it's not needed anymore (it has been fixed upstream during some
  rewrite)
- Drop indus_43092.diff: upstream doesn't want this and we don't
  want to differ there, especially for a theme we don't use as the
  default one.
* Tue Feb 17 2009 vuntz@novell.com
- Update to version 2.17.3:
  + Relicense to LGPL 2.1 or later.
  + Clean up GLib and GTK+ includes (bgo#563787)
  + Focus inconsistent between expander and other widgets in
    Clearlooks (bgo#571835)
  + Updated translations.
- Do not call autoreconf.
- Remove BuildRequires: perl-XML-Parser
* Sat Dec 20 2008 mboman@suse.de
- Update to version 2.17.2:
  + bgo#563256 – 2.17.1 ftbfs
  + A leak in Clearlooks that happened for default buttons was fixed.
  + The Clearlooks inconsistent radio indicator drawing was fixed.
  + bgo#560042 – Sub-optimal -I flag ordering
  + bgo#560443 – GNOME Goal: Remove deprecated GLib symbols
  + bgo#549830 – Use G_DEFINE_DYNAMIC_TYPE in theme engines
  + Focus indicator drawing in Mist
  + Clearlooks now has a disable_focus option to do screenshots for
    documentation
  + Fixed the background color of viewports in notebooks in Clearlooks.
  + bgo#553575 – [PATCH] Only draw focus when navigating with the keyboard
  + bgo#555890 – Button rendering bug
  + Translation updates
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Sun Nov 30 2008 mboman@suse.de
- Fix up .changes as it was not in chronological order.
* Tue Nov 25 2008 sbrabec@suse.cz
- Supplement gtk2-32bit/gtk2-64bit in baselibs.conf (bnc#354164).
* Mon Nov 24 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Wed Oct 22 2008 maw@suse.de
- Update to version 2.16.1:
  + Updated translations.
* Fri Oct  3 2008 mboman@suse.de
- Update to version 2.16.0:
  + Small fix in Clearlooks spinbutton drawing.
  + Translation updates.
* Tue Sep  2 2008 mboman@novell.com
- Updated to version 2.15.4:
  + Reworked Clearlooks gtkrc.
  + Bugs fixed: bgo#549830, bgo#546839, bgo#547024
  + A problem in the glide engine where the drawing of some widgets could
    suddenly disappear forever was fixed.
  + Updated translations
* Tue Aug 12 2008 mboman@novell.com
- Updated to version 2.15.2:
  + The most important change in this release is that the smooth GTK+
    engine has been removed. This engine has long lost its popularity
    and it had a huge codebase that has not been properly maintained
    for years now.
  + Larger menuitem separators in the Clearlooks theme
  + Frame drawing fixes in the Clearlooks engine
  + Padding of progress bars inside menus is fixed in the Industrial theme
  + Fixed bug bgo#511958  - List store tree view contains superfluous
    border (clearlooks)
  + Fixed bug bgo#542625 - 1px gap between notebook at extension
    (industrial)
  + Fixed bug bgo#501734 - Dead code in glide_gtk2_drawing.c
  + Fixed bug bgo#535456 - Unnecessary cast breaks build on Solaris
  + Fixed bug bgo#543608 - Fix for Fortify detected problem
  + Updated translations
- Remove gnome-themes-fortify.patch. It's upstream.
* Fri Jun 27 2008 maw@suse.de
- Remove the %%lang_package macro.
* Thu Jun 26 2008 coolo@suse.de
- there is no -lang package anymore, so don't require it
* Mon Jun 16 2008 maw@suse.de
- Update to version 2.15.1:
  + Schema translations are no longer installed, so the -lang
    subpackage has been dropped
  + Improvements to the Redmond scrollbars, scrolled window and
    menus
  + Various internal changes in the Clearlooks engine
  + Modifications to the "classic" style to be more like the pre
    cairo versions of the engine
  + Bugs fixed: bgo#526890 and bgo#531633
  + Updated translations.
* Thu May 15 2008 olh@suse.de
- remove unneeded Recommends: -64bit on ppc (bnc#390761)
* Tue May 13 2008 sbrabec@suse.cz
- Updated to version 2.14.1:
  * Warning fixes
  * Parser fix in thinice
  * Added a workaround for bgo#514400 (Glitches on panel launcher)
  * Some improvements in Clearlooks (insensitive spinbuttons,
    scales, notebook background color)
  * New and udpated translations
- Enabled lua and animation support.
- Split gtk2-engine-cleanice out and moved to GNOME:Community Build
  Service repository (bnc#380955).
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Fri Mar 14 2008 vuntz@suse.de
- Update to version 2.14.0:
  + Text color fixes and workarounds in the different themes
  + Clearlooks:
  * Correct shadow for insensitive entries
  * Changed contrast handling
  + Crux:
  * Several improvements, this includes spinbuttons and
    comboboxes.
  + bgo#395013: Visual artifacts setting radius to 10.0 (max value)
  + bgo#505334: work around GtkList label colors
  + Updated translations.
- Changes from version 2.13.6:
  + Clearlooks:
  * Fix in the clearlooks schema file. It listed the wrong
    default style.
  * Some small changes in the Clearlooks GUMMY focus drawing.
  + Crux:
  * Lighter background color
  + Updated translations.
- Changes from version 2.13.5:
  + Clearlooks:
  * Read the shadow before drawing toolbars and menubars
  + mist:
  * bgo#500952: check/radio buttons have no insensitive states
  + Updated translations.
* Mon Mar 10 2008 sbrabec@suse.cz
- Added bi-arch counterpart Recommends to prevent arch clashes
  (bnc#354164).
- Added Enhances: gtk2.
* Wed Jan 30 2008 rodrigo@suse.de
- Update to version 2.13.4:
  * Clearlooks progressbar padding inside menus has been fixed
  * New "reliefstyle" option for clearlooks, which controls inset
    vs. shadow around buttons. GUMMY based themes will now use inset
    by default and need to be modified
  * Updated focus drawing for treeviews and notebook tabs in GUMMY
  * bgo#509226: focus rect not painted in aisleriot with clearlooks
  * Updated translations
* Tue Nov 27 2007 prusnak@suse.cz
- removed gtk-xfce-engine [#342676]
* Tue Sep 18 2007 sbrabec@suse.cz
- Updated to version 2.12.0:
  * A set of tweaks to the Clearlooks theme and Gummy engine code
  * Fixed color scheme support in Clearlooks, Crux and Industrial
  * Fixed GTK+ 2.12 tooltips in Clearlooks, Crux, Industrial and
    Thinice
  * Better notebook edge drawing in Clearlooks
  * New and updated translations
* Thu Aug 30 2007 maw@suse.de
- Update to version 2.11.7:
  + Improvements to and cleanups of the clearlooks theme
  + Updated translations.
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage.
* Thu Aug  2 2007 mauro@suse.de
- Update to version 2.11.4
- Small fixes, new ColorScheme, use of CairoColor when available.
* Fri Jul  6 2007 maw@suse.de
- Update to version 2.11.2
- Bug fixes, including bugzilla.gnome.org #429988, #430012,
  [#429761], #429730, #428772, #427265, #438397, #438456, and
  [#413055].
* Mon Mar 26 2007 sbrabec@suse.cz
- Fixed BuildRequires and file list, use %%find_lang.
* Fri Mar 23 2007 maw@suse.de
- Update to version 2.10.0
- Minor changes
- Now requires perl-XML-Parser to build.
* Mon Feb 19 2007 maw@suse.de
- Update to version 2.9.3
- Remove gtk2-engines-missing-return-type.patch which is now
  upstream.
* Tue Dec 19 2006 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Tue Nov 14 2006 jhargadon@suse.de
- added static void return type to engines/crux/src/crux-draw.c
  paint_scale_trough function to resolve defect #217105
* Tue Oct  3 2006 jhargadon@suse.de
- update to version 2.8.1
- Visual improvements to the Crux engine
- Implement "contrast" option in Industrial
- Minor build and information fixes
* Thu Sep 14 2006 jhargadon@suse.de
- update to version 2.8.0
- engines/crux/src/crux-draw.c: (draw_handle): Fix grip position
- themes/Crux/gtk-2.0/gtkrc: Make sure icons are 22x22 in toolbars etc
- themes/Mist/gtk-2.0/gtkrc: Use new Tango blue as "hilight" colour
* Tue Sep  5 2006 ro@suse.de
- autoreconf in cleanice to fix build on x86_64
* Fri Aug 25 2006 jhargadon@suse.de
- update to version 2.7.8
- Add paranoia and deprecated configure flags
- Improve HighContrast (HC) engine inconsistent state check mark
- Use the base/text values for expander arrow in HC
- Improve visibility/contrast of checks in HC
- Fix broken Clearlooks menu on panel check
- Implement a focus rectangle for GtkEntry
- New cairo based Engine called Glide for the Glider theme
- Fixed lots of memory leaks in Clearlooks, and several other bugs
* Thu Aug  3 2006 rml@suse.de
- Update to gtk-engines 2.10 and force rebuild against new gtk2
  * Fixed bugs:
    Bug 342199 - add locking to clearlooks animation code.
    Bug 341694 - Crash in d4x (Industrial)
    Bug 334557 - Compile errors with gcc 2.95 (Clearlooks)
    Bug 333398 - Menubars in panel applets have sunken mode (Clearlooks)
    Bug 317639 - GtkHScale not rendered properly in Clearlooks
    Bug 148848 - No visual difference of disabled checkboxes in SimplySmooth (Smooth)
  * Fixes for notebook dnd releated crash bugs in both industrial and crux.
  * Slightly improved box_gap drawing in crux and industrial.
  * Lots of other miscellaneous fixes
  * Prevent unnecessary symbols from being exported (all engines)
  * Prefix symbols in engines, to prevent possible conflicts with applications
  * Improved RTL support in Clearlooks
* Mon Mar 13 2006 sbrabec@suse.cz
- Added Industrial theme fixes from gnome-themes.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 sbrabec@suse.cz
- Updated to version 2.6.7.
* Wed Nov 30 2005 gekker@suse.de
- Update to version 2.6.6
* Fri Oct  7 2005 sbrabec@suse.cz
- Removed unneeded static modules and .la files for modules.
* Sun Sep  4 2005 jpr@suse.de
- Renable clearlooks, upstream removed clearlooks gtkrc from
  gnome-themes (114702)
* Tue Aug 23 2005 gekker@suse.de
- Update to version 2.6.5
* Tue Aug 16 2005 ro@suse.de
- remove gnome-themes from nfb (not needed and creates cycle)
* Fri Aug 12 2005 ro@suse.de
- removed gtkrc for Clearlooks (now in gnome-themes)
* Thu Aug  4 2005 clahey@suse.de
- Move Industrial gtk2 theme from gnome-themes.
* Tue Aug  2 2005 gekker@suse.de
- Update to version 2.6.4
* Mon Jun 20 2005 gekker@suse.de
- Update to version 2.6.3
* Wed Mar  9 2005 gekker@suse.de
- Update to version 2.6.2 (GNOME 2.10).
* Tue Feb 22 2005 sbrabec@suse.cz
- Package all engines.
* Fri Feb 11 2005 gekker@suse.de
- Update to version 2.6.1
* Sun Feb  6 2005 gekker@suse.de
- Update gtk-engines-cleanice to 2.4.0
- Update gtk-xfce-engine to 2.2.1
* Sat Jan 22 2005 ro@suse.de
- remove files also present in gnome-themes
* Fri Jan 21 2005 clahey@suse.de
- Updated to 2.6.0.
* Fri Jan 14 2005 ro@suse.de
- fix file conflict with gtk2
* Fri Mar 19 2004 pmladek@suse.cz
- fixed bg[SELECTED] to correspond to the color used by the native
  gtk2 widget, bg[SELECTED] is used only by OpenOffice.org now
* Wed Mar 10 2004 hhetter@suse.de
- applied patch to resolve issues with 6nome widget theme
  (and some others) in conjunction with gnumeric crashes
  ( SUSE Bugzilla ID#32861, also related:
  http://bugzilla.gnome.org/show_bug.cgi?id=112066 )
* Sat Mar  6 2004 schwab@suse.de
- Fix doc location.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Thu Oct  9 2003 sbrabec@suse.cz
- Removed thinice engine - now part of gnome-themes.
- Don't package *.la files.
* Wed Jul 23 2003 hhetter@suse.de
- really prefix to /opt/gnome
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Wed Jun 25 2003 sbrabec@suse.cz
- Updated neededforbuild.
- Added xfce and cleanice engines.
* Wed Mar 12 2003 sbrabec@suse.cz
- Fixed prefix clash (fixes bug 25170).
* Thu Feb  6 2003 sbrabec@suse.cz
- Fixed %%files.
- Added gtk-thinice-engine-2.0.2 to package.
* Wed Jan 29 2003 hhetter@suse.de
- up to version 2.2.0
* Tue Jan 14 2003 ro@suse.de
- use wildcard in filelist for gtk2-version
* Fri Jun 21 2002 hhetter@suse.de
- initial SuSE package
